# coding:utf-8
from django.template.loader import render_to_string
from educommon.django.db.model_view import registries
from educommon.utils.ui import local_template
from m3_ext.ui.containers.forms import ExtPanel
from objectpack.ui import BaseWindow


class RelatedObjectsWindow(BaseWindow):

    u"""Окно с информацией о зависимых объектах.

    Используется для отображения информации об объектах, зависящих от
    удаляемых.

    В параметрах окна должен быть указан список удаляемых объектов и список
    объектов, зависимых от удаляемых.
    """

    #: Шаблон HTML-страницы с представлениями моделей.
    html_template = local_template('related-objects-window.html')

    @property
    def model_view_registry(self):
        u"""Реестр представлений моделей."""
        return registries['related_objects']

    def _init_components(self):
        super(RelatedObjectsWindow, self)._init_components()

        self.panel = ExtPanel(
            auto_scroll=True,
            cls='related-objects',
        )
        self.items.append(self.panel)

    def _do_layout(self):
        super(RelatedObjectsWindow, self)._do_layout()

        self.width = 800
        self.height = 600

        self.layout = 'fit'

    def _get_html(self, title, objects, related_objects):
        views = tuple(
            self.model_view_registry.get(model).get_view(objects)
            for model, objects in related_objects.iteritems()
        )

        return render_to_string(
            template_name=self.html_template,
            context=dict(
                title=title,
                views=views,
            ),
        )

    def set_params(self, params):
        super(RelatedObjectsWindow, self).set_params(params)

        self.title = u"Внимание!"

        self.panel.html = self._get_html(
            params.get('title'),
            params['objects'],
            params['related_objects'],
        )
